diff include/ReceiveAudioThread.h @ 301:e4392164b458 prerelease

RENAMED BeagleRT to Bela AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA, scripts probably not working
author Giulio Moro <giuliomoro@yahoo.it>
date Fri, 27 May 2016 14:34:41 +0100
parents c42a6b4dc2d4
children
line wrap: on
line diff
--- a/include/ReceiveAudioThread.h	Fri May 27 13:58:20 2016 +0100
+++ b/include/ReceiveAudioThread.h	Fri May 27 14:34:41 2016 +0100
@@ -4,7 +4,7 @@
 #ifdef USE_JUCE
 #include <JuceHeader.h>
 #else
-#include <BeagleRT.h>
+#include <Bela.h>
 #include <UdpServer.h>
 #include <vector>
 #include <iostream>
@@ -95,8 +95,8 @@
     void run();
 #else
     RTIME getLastTime();
-    void static run(); //while in BeagleRT we have a single thread that receives for all the instances.
-    //TODO: make run() private in BeagleRT
+    void static run(); //while in Bela we have a single thread that receives for all the instances.
+    //TODO: make run() private in Bela
     static void startThread();
     static void stopThread();
     static int getNumInstances();